@@ -43,23 +43,15 @@ from logging import getLogger
 
 from django.http import HttpResponse
 from django.http import HttpResponseServerError
-from django.shortcuts import render_to_response
-from django.template import RequestContext
+from django.shortcuts import render
 from django.views.decorators.csrf import csrf_exempt
 
-from django_xmlrpc.decorators import xmlrpc_func
 from django_xmlrpc.dispatcher import xmlrpc_dispatcher
 
 
 logger = getLogger('xmlrpc.views')
 
 
-@xmlrpc_func(returns='string', args=['string'])
-def test_xmlrpc(text):
-    """Simply returns the args passed to it as a string"""
-    return "Here's a response! %s" % str(text)
-
-
 @csrf_exempt
 def handle_xmlrpc(request):
     """Handles XML-RPC requests. All XML-RPC calls should be forwarded here
@@ -94,6 +86,4 @@ def handle_xmlrpc(request):
 
             method_list.append((method, sig, method_help))
 
-        return render_to_response(
-            'xmlrpc_get.html',
-            RequestContext(request, {'methods': method_list}))
+        return render(request, 'xmlrpc_get.html', {'methods': method_list})
